==> keras-cv-0.2.10.tar.gz: keras-cv-0.2.10/setup.py <==
# Copyright 2019 The KerasCV Authors
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""Setup script."""

import pathlib

from setuptools import find_packages
from setuptools import setup

HERE = pathlib.Path(__file__).parent
README = (HERE / "README.md").read_text()

setup(
    name="keras-cv",
    description="Industry-strength computer Vision extensions for Keras.",
    long_description=README,
    long_description_content_type="text/markdown",
    url="https://github.com/keras-team/keras-cv",
    author="Keras team",
    author_email="keras-cv@google.com",
    license="Apache License 2.0",
    install_requires=["packaging", "absl-py"],
    python_requires=">=3.7",
    extras_require={
        "tests": ["flake8", "isort", "black", "pytest"],
        "examples": ["tensorflow_datasets", "matplotlib"],
    },
    classifiers=[
        "Programming Language :: Python",
        "Programming Language :: Python :: 3.7",
        "Operating System :: Unix",
        "Operating System :: Microsoft :: Windows",
        "Operating System :: MacOS",
        "Intended Audience :: Science/Research",
        "Topic :: Scientific/Engineering",
        "Topic :: Software Development",
    ],
    packages=find_packages(exclude=("*_test.py",)),
)

==> keras-cv-0.3.1.tar.gz: keras-cv-0.3.1/setup.py <==
# Copyright 2019 The KerasCV Authors
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""Setup script."""

import pathlib

from setuptools import find_packages
from setuptools import setup

HERE = pathlib.Path(__file__).parent
README = (HERE / "README.md").read_text()

setup(
    name="keras-cv",
    description="Industry-strength computer Vision extensions for Keras.",
    long_description=README,
    long_description_content_type="text/markdown",
    url="https://github.com/keras-team/keras-cv",
    author="Keras team",
    author_email="keras-cv@google.com",
    license="Apache License 2.0",
    install_requires=["packaging", "absl-py", "tensorflow_datasets"],
    python_requires=">=3.7",
    extras_require={
        "tests": ["flake8", "isort", "black", "pytest"],
        "examples": ["tensorflow_datasets", "matplotlib"],
    },
    classifiers=[
        "Programming Language :: Python",
        "Programming Language :: Python :: 3.7",
        "Operating System :: Unix",
        "Operating System :: Microsoft :: Windows",
        "Operating System :: MacOS",
        "Intended Audience :: Science/Research",
        "Topic :: Scientific/Engineering",
        "Topic :: Software Development",
    ],
    packages=find_packages(exclude=("*_test.py",)),
)
